@@ -1,21 +1,20 @@
 /*
-   Author: Anand Avati <avati@zresearch.com>
-   (C) 2005,2006 FreeTalk Core Team
-   
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) any later version.
-    
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-    
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+  This file is part of GNU Freetalk.
+
+  Freetalk is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -57,6 +56,27 @@ do_connect_common ()
   lm_connection_ref (state.conn);
   do_set_conn_status (FT_DEAD);
 
+  /* Proxy Support */
+
+  if (state.need_proxy) {
+
+    if (!state.proxyserver) 
+      return -5;
+
+    state.proxy = lm_proxy_new_with_server (LM_PROXY_TYPE_HTTP,
+					    state.proxyserver,
+					    state.proxyport);
+    if (!state.proxyuname) state.proxyuname = NULL;
+    if (!state.proxypasswd) state.proxypasswd = NULL;
+    
+    lm_proxy_set_username (state.proxy, state.proxyuname);
+    lm_proxy_set_password (state.proxy, state.proxypasswd);
+    
+    lm_connection_set_proxy (state.conn, state.proxy);
+    lm_proxy_unref(state.proxy);
+  }
+
+
   lm_connection_set_jid (state.conn, state.jid_str);
 
   if (state.need_ssl) {
@@ -303,8 +323,17 @@ do_send_message_no_hook (char *jid, char *msg_str)
     return -1;
 
   msg = lm_message_new (jid, LM_MESSAGE_TYPE_MESSAGE);
-  lm_message_node_set_attribute (msg->node, "type", "chat");
-  lm_message_node_add_child (msg->node, "body", msg_str);
+
+  //  Intermediate Invisible mode messaging fix : TODO
+  //if (!strcmp (do_get_status_msg (), "invisible")) {
+  //  lm_message_node_set_attribute (msg->node, "type", "chat");
+  //  lm_message_node_add_child (msg->node, "body", msg_str);
+  //  lm_message_node_add_child (msg->node, "priority", priority);
+  //} else {
+    lm_message_node_set_attribute (msg->node, "type", "chat");
+    lm_message_node_add_child (msg->node, "body", msg_str);
+    //}
+
   return lm_connection_send (state.conn, msg, NULL);
 }
 
@@ -429,7 +458,7 @@ do_add (char *jid)
 int
 do_set_status_msg (char *status)
 {
-  const char *valid[] = { "online", "away", "chat", "xa", "dnd", NULL }, *text = NULL;
+  const char *valid[] = { "online", "away", "chat", "xa", "dnd", "invisible", NULL }, *text = NULL;
   int show, offset;
   
   if((text = strchr(status, ' '))) {
@@ -444,7 +473,7 @@ do_set_status_msg (char *status)
     }
   }
   if( !valid[show] ) {
-    PRINTF ("Status must be one of [online|away|chat|xa|dnd]");
+    PRINTF ("Status must be one of [online|away|chat|xa|dnd|invisible]");
     return -1;
   }
   if (state.status_msg)
@@ -453,7 +482,11 @@ do_set_status_msg (char *status)
 
   LmMessage *msg = lm_message_new (NULL, LM_MESSAGE_TYPE_PRESENCE);
   if( show != 0 ) { // online status is implicit
-    lm_message_node_add_child (msg->node, "show", valid[show]);
+    if (!strcmp (valid[show], "invisible")) {
+      lm_message_node_set_attribute (msg->node, "type", "unavailable");
+    } else {
+      lm_message_node_add_child (msg->node, "show", valid[show]);
+    }
   }
   if( text != NULL ) {
     lm_message_node_add_child (msg->node, "status", text);
@@ -549,3 +582,89 @@ do_change_password (char *npass)
     }
   free (npass);
 }
+
+int 
+do_set_proxy (char value)
+{
+  state.need_proxy = value;
+  return 0;
+}
+
+int 
+do_get_proxy (void)
+{
+  return state.need_proxy;
+}
+
+const char *
+do_get_proxyserver (void)
+{
+  return state.proxyserver ? state.proxyserver : "";
+}
+
+int 
+do_get_proxyport (void)
+{
+  return state.proxyport;
+}
+
+int 
+do_set_proxyserver (const char *proxyserver)
+{
+  if (!proxyserver) 
+    return -1;
+  
+  if (state.proxyserver)
+    free (state.proxyserver);
+  state.proxyserver = strdup (proxyserver);
+  return 0;
+}
+
+int
+do_set_proxyport (unsigned short int proxyport)
+{
+  state.proxyport = proxyport;
+  return 0;
+}
+
+
+const char *
+do_get_proxyuname (void) 
+{
+  return state.proxyuname ? state.proxyuname : "";
+}
+
+const char *
+do_get_proxypasswd (void)
+{
+  return state.proxypasswd ? state.proxypasswd : "";
+}
+
+int 
+do_set_proxyuname (const char *proxyuname) 
+{
+  if (!proxyuname) 
+    return -1;
+
+  if (state.proxyuname)
+    free (state.proxyuname);
+
+  state.proxyuname = strdup (proxyuname);
+
+  return 0;
+}
+
+int 
+do_set_proxypasswd (const char *proxypasswd) 
+{
+  if (!proxypasswd) 
+    return -1;
+
+  if (state.proxypasswd)
+    free (state.proxypasswd);
+
+  state.proxypasswd = strdup (proxypasswd);
+
+  return 0;
+}
+
