@@ -1,21 +1,20 @@
 /*
-  Author: Basavanagowda Kanur <gowda@freeshell.in>
-  (C) 2005,2006 Freetalk core team <http://www.gnu.org/software/freetalk/>
-  
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License, or (at your option) any later version.
-    
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-    
-  You should have received a copy of the GNU General Public
-  License along with this program; if not, write to the Free
-  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301 USA
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+  This file is part of GNU Freetalk.
+
+  Freetalk is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 */
 
 /* Status->
@@ -33,7 +32,7 @@
 #include "freetalk.h"
 #include "extensions.h"
 #include "file_transfer.h"
-
+#include "compat.h"
 
 /* file-transfer: implementation howto
  *
@@ -219,7 +218,7 @@ int ft_msg_sub_type_set_cb(LmMessage *msg)
 	g_free (incoming.sender);
       
       /* Before sending the 'result' reply, open the file to write to */
-      if ((file->fd = open (file->local_file, O_CREAT | O_WRONLY)) < 0){
+      if ((file->fd = open (file->local_file, O_CREAT | O_WRONLY, S_IWUSR)) < 0){
 	scm_run_hook (ex_notify_file_hook, scm_list_n (scm_from_locale_string (file->sender),
 						       scm_from_locale_string (file->local_file),
 						       scm_from_int (FT_FILE_NO_OPEN),
